import math
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D

def scaling(x): #x is a list of points. Each point is a list.
    num = len(x)-1 #num = number of points
    x_new = [list(np.array(point)[:num]/point[3]) for point in x]
    return x_new

   

def show_outline(coords):
    """
    inputs: a list, coords, of coordinates of the vertices of the polygon we want to construct. We assume these coordinates,
            in the given order, do form a polygon on the (projected) boundary at infinity of Anti de-Sitter space.
            
    outputs: saves a file with a 3d graph containing the desired polygon, outlined on the projection of Ads.
    """
    x = []
    y = []
    z = []
    for idx in range(len(coords)):
        x.append(coords[idx][0])
        y.append(coords[idx][1])
        z.append(coords[idx][2])
    fig = plt.figure(figsize=(15, 15))
    ax = plt.axes(projection = '3d')
    ax.plot3D(x, y, z, alpha=0.7)

    angle = np.linspace(0, 2 * np.pi, 50)
    time = np.linspace(-3, 3, 3000)
    t, theta = np.meshgrid(time, angle)
    X2 = np.sqrt(1 + t ** 2) * np.cos(theta)
    Y2 = np.sqrt(1 + t ** 2) * np.sin(theta)
    Z2 = t
    ax.plot_surface(X2, Y2, Z2, color='grey', alpha=0.2)
    ax.view_init(30, 150)
    return ax

